@@ -67,15 +67,6 @@ if (
     );
 }
 
-# Display captcha if it's enabled
-if ( $portal->{captcha_enabled} ) {
-    $template->param(
-        CAPTCHA_IMG  => $portal->{captcha_img},
-        CAPTCHA_CODE => $portal->{captcha_code},
-        CAPTCHA_SIZE => $portal->{captcha_size}
-    );
-}
-
 # Display mail confirmation resent form
 if ( $portal->{error} == PE_MAILCONFIRMATION_ALREADY_SENT ) {
     $template->param(
