@@ -9,13 +9,12 @@ use strict;
 use Lemonldap::NG::Portal::Simple qw(:all);
 use Lemonldap::NG::Common::Conf;            #link protected lmConf Configuration
 use Lemonldap::NG::Common::Conf::Constants; #inherits
-use Regexp::Assemble;
 
 *EXPORT_OK   = *Lemonldap::NG::Portal::Simple::EXPORT_OK;
 *EXPORT_TAGS = *Lemonldap::NG::Portal::Simple::EXPORT_TAGS;
 *EXPORT      = *Lemonldap::NG::Portal::Simple::EXPORT;
 
-our $VERSION = '1.2.2_01';
+our $VERSION = '1.2.0';
 use base qw(Lemonldap::NG::Portal::Simple);
 our $confCached;
 
@@ -57,24 +56,34 @@ sub getConf {
                 $Lemonldap::NG::Common::Conf::msg );
         }
         %$confCached = ( %$gConf, %$lConf );
-
-        my $re = Regexp::Assemble->new();
-        foreach ( keys %{ $confCached->{locationRules} } ) {
-            $_ = quotemeta($_);
-            $re->add($_);
-        }
-        $confCached->{reVHosts} = $re->as_string;
-
     }
 
     %$self = ( %$self, %$confCached, %args, );
 
+    # localStorage should be declared in configuration object
+    # See Handler::SharedConf
+    foreach (qw(localStorage localStorageOptions)) {
+        $self->{$_} ||= $self->__lmConf->{$_};
+    }
+
     $self->lmLog( "Now using configuration: " . $confCached->{cfgNum},
         'debug' );
 
     1;
 }
 
+## @method list getProtectedSites()
+# With SharedConf, $locationRules contains a hash table with virtual hosts as
+# keys. So we can use it to know all protected virtual hosts.
+# @return list list of protected virtual hosts.
+sub getProtectedSites {
+    my $self = shift;
+    my @tab  = ();
+    return ( keys %{ $self->{locationRules} } )
+      if ( ref $self->{locationRules} );
+    return ();
+}
+
 sub __lmConf {
     my $self = shift;
     return $self->{lmConf} if ( $self->{lmConf} );
@@ -206,8 +215,15 @@ L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>,
-Thomas Chemineau, E<lt>thomas.chemineau@linagora.comE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=back
 
 =head1 BUG REPORT
 
@@ -221,11 +237,27 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005, 2007, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt> and
-Thomas Chemineau, E<lt>thomas.chemineau@linagora.comE<gt>
+=over
+
+=item Copyright (C) 2006, 2007, 2008, 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2006, 2009, 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
